@@ -3,7 +3,7 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 **
-** (c) 2005-2008 Jakson Aquino: jalvesaq@gmail.com
+** (c) 2005-2011 Jakson Aquino: jalvesaq@gmail.com
 **
 ***************************************************************/
 
@@ -197,11 +197,11 @@ void on_sobre1_activate(){
   GtkWidget *dialog;
   dialog = gtk_message_dialog_new (GTK_WINDOW (window1), GTK_DIALOG_MODAL | 
       GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, _(
-      "gconjugue %s\n(c) 2005-2008 Jakson A. Aquino <jalvesaq@gmail.com>\n\n"
+      "gconjugue %s\n(c) 2005-2011 Jakson A. Aquino <jalvesaq@gmail.com>\n\n"
       "gconjugue is based on \"conjugue\", "
       "which was developed by Ricardo Ueda Karpischek\n\n"
       "gconjugue is free software under GNU GPL license.\n\n"
-      "Homepage:\nhttp://jalvesaq.googlepages.com/gconjugue.html"), VERSION);
+      "Homepage:\nhttp://sites.google.com/site/jalvesaq/gconjugue"), VERSION);
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 }
@@ -274,7 +274,7 @@ void read_verb(){
   GtkEntry *e = (GtkEntry*)entry1;
   const char *vrb = gtk_entry_get_text(e);
   conjugar(vrb);
-  gtk_editable_select_region(GTK_EDITABLE(e), 0, e->text_length);
+  gtk_editable_select_region(GTK_EDITABLE(e), 0, gtk_entry_get_text_length(e));
 }
 
 void on_btconjg_clicked(){
