@@ -3,7 +3,7 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 2005-2008 Jakson Aquino: jalvesaq@gmail.com
+** (c) 2005-2011 Jakson Aquino: jalvesaq@gmail.com
 **
 ***************************************************************/
 
@@ -298,13 +298,22 @@ int conjugue(char *v, char *buffer){
     P = V->p;
     adicionar(buffer, "\3Paradigma: %s\5\n\n", P->paradigma);
     if(strcmp(V->p->paradigma, "doer") == 0)
-      adicionar(buffer, "\2Observação: Doer e condoer são irregulares e defectivos, só se conjugando nas terceiras pessoas. Por outro lado,\5 \3doer-se\5 \2e\5 \3condoer-se\5 \2conjugam-se em todas as pessoas, por isso estamos indicando aqui a conjugação completa.\5\n\n");
+      adicionar(buffer, "\2Observação: Doer e condoer são irregulares e "
+	  "defectivos, só se conjugando nas terceiras pessoas. Por outro "
+	  "lado,\5 \3doer-se\5 \2e\5 \3condoer-se\5 \2conjugam-se em todas "
+	  "as pessoas, por isso estamos indicando aqui a conjugação "
+	  "completa.\5\n\n");
   } else{
+    i = strlen(v);
+    if(v[i-1] != 'r'){
+      adicionar(buffer, "\2“%s” não é verbo ou não está no infinitivo.\n\5", v);
+      return 0;
+    }
     P = deduzirParadigma(v);
     if(P)
       adicionar(buffer, "\3Paradigma deduzido: %s\5\n\n", P->paradigma);
     else {
-      adicionar(buffer, "\2Não sei conjugar \"%s\"\n\5", v);
+      adicionar(buffer, "\2Não sei conjugar “%s”\n\5", v);
       return 0;
     }
   }
@@ -554,7 +563,7 @@ Paradigma *restaurarParadigma(char *s)
       return(P);
     }
   if(i == np){
-    fprintf(stderr, "Erro: paradigma \"%s\" não encontrado.\n", verbo);
+    fprintf(stderr, "Erro: paradigma “%s” não encontrado.\n", verbo);
     exit(1);
   }
   return NULL;
@@ -778,8 +787,8 @@ void compare(){
   fclose(C);
 
   fprintf(stderr, "%s = %d, %s = %d\n", _("paradigms"), np, _("verbs"), nv);
-  fprintf(stderr, _("See the files %s, %s, and %s"), "\"listaDeVerbos\"",
-      "\"listaDeParadigmas\"", "\"todosOsVerbos\"\n");
+  fprintf(stderr, _("See the files %s, %s, and %s"), "“listaDeVerbos”",
+      "“listaDeParadigmas”", "“todosOsVerbos”\n");
 }
 
 int compareVerbs(const void *a, const void *b)
@@ -848,7 +857,7 @@ void listVerbs(char *buffer)
     } else{
       P = deduzirParadigma(vrb[i].v);
       if(P == NULL)
-	sprintf(str, "\2ERRO tentando deduzir paradigma do verbo \"%s\".\5\n", vrb[i].v);
+	sprintf(str, "\2ERRO tentando deduzir paradigma do verbo “%s”.\5\n", vrb[i].v);
       else
 	sprintf(str, "%s (%s)\n", vrb[i].v, P->paradigma);
     }
