@@ -3,7 +3,7 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 2005-2008 Jakson Aquino: jalvesaq@gmail.com
+** (c) 2005-2011 Jakson Aquino: jalvesaq@gmail.com
 **
 ***************************************************************/
 
@@ -66,7 +66,7 @@ void initialize(int argc, char *argv[])
     exit(0);
   }
 
-  gtk_set_locale ();
+  setlocale (LC_ALL, "");
   gtk_init (&argc, &argv);
 
   window1 = create_window1 ();
